/**
 *
 * Copyright 2019 Florian Schmaus
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jivesoftware.smackx.xdata.provider;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import javax.xml.namespace.QName;

public class FormFieldChildElementProviderManager {

    private static final Map<QName, FormFieldChildElementProvider<?>> providers = new ConcurrentHashMap<>();

    public static void addFormFieldChildElementProvider(
                    FormFieldChildElementProvider<?>... formFieldChildElementProviders) {
        for (FormFieldChildElementProvider<?> formFieldChildElementProvider : formFieldChildElementProviders) {
            QName qname = formFieldChildElementProvider.getQName();
            providers.put(qname, formFieldChildElementProvider);
        }
    }

    public static FormFieldChildElementProvider<?> addFormFieldChildElementProvider(QName qname,
                    FormFieldChildElementProvider<?> formFieldChildElementProvider) {
        return providers.put(qname, formFieldChildElementProvider);
    }

    public static FormFieldChildElementProvider<?> getFormFieldChildElementProvider(QName qname) {
        return providers.get(qname);
    }

}
